| Title: | Single Cell Cluster-Based Annotation Toolkit for Cellular Heterogeneity |
|---|---|
| Description: | An automatic cluster-based annotation pipeline based on evidence-based score by matching the marker genes with known cell markers in tissue-specific cell taxonomy reference database for single-cell RNA-seq data. See Shao X, et al (2020) <doi:10.1016/j.isci.2020.100882> for more details. |
| Authors: | Xin Shao |
| Maintainer: | Xin Shao<[email protected]> |
| License: | GPL (>= 3) |
| Version: | 3.2.2 |
| Built: | 2026-06-08 08:49:25 UTC |
| Source: | https://github.com/zjufanlab/sccatch |
Marker genes of 'Human' and 'Mouse'.
cellmatchcellmatch
An object of class data.frame with 49560 rows and 11 columns.
https://github.com/ZJUFanLab/scCATCH/tree/master/data
create scCATCH object using single-cell count data and cluster information.
createscCATCH(data, cluster)createscCATCH(data, cluster)
data |
A matrix or dgCMatrix containing normalized single-cell RNA-seq data, each column representing a cell, each row representing a gene. See |
cluster |
A character containing the cluster information for each cell. The length of it must be equal to the ncol of the data. |
scCATCH object
Demo data of single-cell RNA-seq data
demo_data()demo_data()
data used in createscCATCH must be a matrix object, each column representing a cell, each row representing a gene.
A demo data matrix.
data_demo <- demo_data()data_demo <- demo_data()
Demo data of geneinfo
demo_geneinfo()demo_geneinfo()
geneinfo used in rev_gene must be a data.frame object with three columns, namely 'symbol', 'synonyms', 'species'.
A demo geneinfo data.frame.
geneinfo_demo <- demo_geneinfo()geneinfo_demo <- demo_geneinfo()
Demo data of markers
demo_marker()demo_marker()
markers used in findmarkergene must be a data.frame object with eleven columns.
A demo marker data.frame.
markers_demo <- demo_marker()markers_demo <- demo_marker()
Evidence-based score and annotation for each cluster.
findcelltype(object, verbose = TRUE)findcelltype(object, verbose = TRUE)
object |
scCATCH object generated from |
verbose |
Show progress messages. |
scCATCH object containing the results of predicted cell types for each cluster.
Identify potential marker genes for each cluster.
findmarkergene( object, species = NULL, cluster = "All", if_use_custom_marker = FALSE, marker = NULL, cancer = "Normal", tissue = NULL, use_method = "1", comp_cluster = NULL, cell_min_pct = 0.25, logfc = 0.25, pvalue = 0.05, verbose = TRUE )findmarkergene( object, species = NULL, cluster = "All", if_use_custom_marker = FALSE, marker = NULL, cancer = "Normal", tissue = NULL, use_method = "1", comp_cluster = NULL, cell_min_pct = 0.25, logfc = 0.25, pvalue = 0.05, verbose = TRUE )
object |
scCATCH object generated from |
species |
The specie of cells. The species must be defined. 'Human' or 'Mouse'. When if_use_custom_marker is set TRUE, no need to define the species. |
cluster |
Select which clusters for potential marker genes identification. e.g. '1', '2', etc. The default is 'All' to find potential makrer genes for each cluster. |
if_use_custom_marker |
Whether to use custom markers data.frame. |
marker |
A data.frame containing marker genes. See |
cancer |
If the sample is from cancer tissue, then the cancer type may be defined. When if_use_custom_marker is set TRUE, no need to define the cancer. |
tissue |
Tissue origin of cells must be defined. Select one or more related tissue types. When if_use_custom_marker is set TRUE, no need to define the tissue. |
use_method |
'1' is to compare with other every cluster. '2' is to compare with other clusters together. |
comp_cluster |
Number of clusters to compare. Default is to compare all other cluster for each cluster. Set it between 1 and length of unique clusters. More marker genes will be obtained for smaller comp_cluster. |
cell_min_pct |
Include the gene detected in at least this many cells in each cluster. |
logfc |
Include the gene with at least this fold change of average gene expression compared to every other clusters. |
pvalue |
Include the significantly highly expressed gene with this cutoff of p value from wilcox test compared to every other clusters. |
verbose |
Show progress messages. |
Details of available tissues see https://github.com/ZJUFanLab/scCATCH/wiki
scCATCH object
Gene symbols of 'Human' and 'Mouse' updated on Jan. 2, 2022 for revising genes.
geneinfogeneinfo
An object of class data.frame with 240502 rows and 3 columns.
https://www.ncbi.nlm.nih.gov/gene
Revise genes according to NCBI Gene symbols updated in June 19, 2022 for count matrix, user-custom cell marker data.frame.
rev_gene(data = NULL, data_type = NULL, species = NULL, geneinfo = NULL)rev_gene(data = NULL, data_type = NULL, species = NULL, geneinfo = NULL)
data |
A matrix or dgCMatrix containing count or normalized data, each column representing a spot or a cell, each row representing a gene; Or a data.frame containing cell markers, use |
data_type |
A character to define the type of |
species |
Species of the data. |
geneinfo |
A data.frame of the system data containing gene symbols of |
A new matrix or data.frame.
An S4 class containing the data, meta, and results of inferred cell types.
dataA list containing normalized data. See demo_data.
metaA data frame containing the meta data.
paraA list containing the parameters.
markergeneA data frame containing the identified markers for each cluster.
celltypeA data frame containing the cell types for each cluster.
markerA data frame containing the known markers. See demo_marker.